@@ -1,13 +1,14 @@
-from typing import Optional
+from __future__ import annotations
 
 from blessed.keyboard import Keystroke
 
 from . import keys
-from .types import DurationMode, Flag, QueryDisplayMode, QueryMode, SortKey, enum_next
+from .config import Flag
+from .types import DurationMode, QueryMode, SortKey, enum_next
 
 
 def refresh_time(
-    key: Optional[str], value: float, minimum: float = 0.5, maximum: float = 5
+    key: str | None, value: float, minimum: float = 0.5, maximum: float = 5
 ) -> float:
     """Return an updated refresh time interval from input key respecting bounds.
 
@@ -50,22 +51,22 @@ def duration_mode(key: Keystroke, mode: DurationMode) -> DurationMode:
     return mode
 
 
-def query_display_mode(key: Keystroke, mode: QueryDisplayMode) -> QueryDisplayMode:
-    """Return the updated query display mode matching input key.
+def wrap_query(key: Keystroke, wrap: bool) -> bool:
+    """Return the updated 'wrap' value depending on input key.
 
     >>> from blessed.keyboard import Keystroke as k
 
-    >>> query_display_mode(k("42"), QueryDisplayMode.truncate).name
-    'truncate'
-    >>> query_display_mode(k("v"), QueryDisplayMode.wrap_noindent).name
-    'wrap'
+    >>> wrap_query(k("42"), True)
+    True
+    >>> wrap_query(k("v"), False)
+    True
     """
-    if key == keys.CHANGE_DISPLAY_MODE:
-        return enum_next(mode)
-    return mode
+    if key == keys.WRAP_QUERY:
+        return not wrap
+    return wrap
 
 
-def query_mode(key: Keystroke) -> Optional[QueryMode]:
+def query_mode(key: Keystroke) -> QueryMode | None:
     """Return the query mode matching input key or None.
 
     >>> import curses
@@ -85,9 +86,7 @@ def query_mode(key: Keystroke) -> Optional[QueryMode]:
     return keys.QUERYMODE_FROM_KEYS.get(key)
 
 
-def sort_key_for(
-    key: Keystroke, query_mode: QueryMode, flag: Flag
-) -> Optional[SortKey]:
+def sort_key_for(key: Keystroke, query_mode: QueryMode, flag: Flag) -> SortKey | None:
     """Return the sort key matching input key or None.
 
     >>> from blessed.keyboard import Keystroke as k
